% Plot_Modes.m
%
% This code provides an example of how to extract and plot the measured
% mode shapes of the thin panel. The modal frequencies and damping are also
% provided in the title of the figure for each mode.
%
% The panel geometry data are contained in the matlab file
% RC19_Setup_[Case ID].mat. The file contains several variables.
% However, only the following structure variables are used in this code:
%
%   Panel_Geom - structure variable with the following fields:
%       - Lpanel_m          : Length of thin panel, scalar
%       - Wpanel_m          : Width of thin panel, scalar
%       - Tpanel_m          : Thickness of thin panel, scalar
%       - Measured_Modes    : Includes the mesh, X_m and Y_m, the measured
%                             modes scaled to have a range of [-1,1],
%                             Shape_unit, the measured frequencies, f_Hz,
%                             and the measured damping, Damp_percent
%       - f1_installed_Hz   : Fundamental frequency of the installed panel
%
%
% Notes:
%   - The origin (0,0,0) is assumed to be at the leading edge of the thin
%     panel along the mid-span and mid-height.
%   - The RC-19 tunnel has a rectangular cross-section
%   - All units are provided in the variable name after the last underscore
%     and are all in METRIC
%   - The positive x-direction is taken as the streamwise direction
%
% Code originally written by Kirk Brouwer.
% Distribution A, Cleared for Public Release on 4 October 2021.
%
clc;
clearvars;
close all;
%
%%%%%%%%%%%%%%%%%%%%
% File Definitions %
%%%%%%%%%%%%%%%%%%%%
Case = 'SeparatedSBLI_Periodic';
%
%%%%%%%%%%%%%
% Load Data %
%%%%%%%%%%%%%
load(['RC19_Setup_',Case,'.mat']);
Nmodes = size(Panel_Geom.MeasuredModes.Shape_unit,3);
%
%%%%%%%%%%%%%%%%%%%%
% Plot Mode Shapes %
%%%%%%%%%%%%%%%%%%%%
for k = 1:Nmodes
    figure;
    tri = delaunay(Panel_Geom.MeasuredModes.X_m,Panel_Geom.MeasuredModes.Y_m);
    hMean = trisurf(tri,Panel_Geom.MeasuredModes.X_m,Panel_Geom.MeasuredModes.Y_m,...
        Panel_Geom.MeasuredModes.Shape_unit(:,:,k));
    colormap(jet(1e5));
    hMean.EdgeColor = 'none';
    shading interp;
    xlim([0,0.254]);
    ylim([-0.127/2,0.127/2]);
    view([0,90]);
    xlabel('x (m)');
    ylabel('y (m)');
    if (k == 1)
        title(['Mode ',num2str(k),': f_{pre-test} = ',...
            num2str(Panel_Geom.MeasuredModes.f_Hz(k)),...
            ' Hz, \zeta_{pre-test} = ',...
            num2str(Panel_Geom.MeasuredModes.Damp_percent(k)),...
            ' %, f_{installed} = ',num2str(Panel_Geom.f1_installed_Hz),' Hz']);
    else
        title(['Mode ',num2str(k),': f_{pre-test} = ',...
            num2str(Panel_Geom.MeasuredModes.f_Hz(k)),...
            ' Hz, \zeta_{pre-test} = ',...
            num2str(Panel_Geom.MeasuredModes.Damp_percent(k)),' %']);
    end
    set(gca,'FontSize',12);
end
%