% Plot_Tunnel.m
%
% This code provides an example of how to extract and plot various slices 
% of the RC-19 tunnel with the nominal Mach 2.0 nozzle. The tunnel geometry 
% includes the nozzle and test section. A plot is provided at the end of 
% the script that illustrates the different sections of the tunnel as well 
% as the location of the thin panel. The wedge for the selected case is 
% also plotted at the estimated position.
%
% The tunnel and panel geometry data are contained in the matlab file
% RC19_Setup_[Case ID].mat. The file contains several variables. 
% However, only the following structure variables are used in this code:
%
%   Tunnel_Geom - structure variable with the following fields:
%       - Lnozzle_m         : Length of nozzle, scalar
%       - Wnozzle_m         : Width of nozzle, scalar
%       - NozzleSlice_m     : x and z locations of nominal Mach 2 nozzle,
%                             (Nx2) matrix with x and z values in the first 
%                             column and second column, respectively
%       - Ltest_m           : Length of test section, scalar
%       - Htest_m           : Height of test section, scalar
%       - Wtest_m           : Width of test section (equal to Wnozzle), scalar
%       - TestStart_m       : Distance in x from the start of test section 
%                             to the panel leading edge
%
%   Panel_Geom - structure variable with the following fields:
%       - Lpanel_m          : Length of thin panel, scalar
%       - Wpanel_m          : Width of thin panel, scalar
%       - Lframe_m          : Frame length (includes Lpanel_m), scalar
%       - Wframe_m          : Frame width (includes Wpanel_m), scalar
%
%   Wedge_Geom - Structure variable with the following fields:
%       - Lwedge_m          : Length of wedge, 1 x 2 array
%       - Hwedge_m          : Height of wedge, 1 x 2 array
%       - Wwedge_m          : Width of wedge, scalar
%       - WedgeLE2PanelLE_m : Estimated distance from the leading edge of
%                             the wedge to the leading edge of the thin 
%                             panel, 1 x 2 array
%
% Notes:
%   - The origin (0,0,0) is assumed to be at the leading edge of the thin
%     panel along the mid-span and mid-height.
%   - The RC-19 tunnel has a rectangular cross-section
%   - All units are provided in the variable name after the last underscore
%     and are all in METRIC
%   - The positive x-direction is taken as the streamwise direction
%
% Code originally written by Kirk Brouwer.
% Distribution A, Cleared for Public Release on 4 October 2021.
%
clc;
clearvars;
close all;
%
%%%%%%%%%%%%%%%%%%%%
% File Definitions %
%%%%%%%%%%%%%%%%%%%%
Case = 'NoSBLI_Periodic';
%
%%%%%%%%%%%%%
% Load Data %
%%%%%%%%%%%%%
load(['RC19_Setup_',Case,'.mat']);
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute Variables for Plotting %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if strcmp(Case,'SeparatedSBLI_Periodic') || strcmp(Case,'AttachedSBLI_Periodic')
    isShock = 1;
else
    isShock = 0;
end
%
% Shift nozzle x-locations (given in NozzleSlice) so that the end of the
% nozzle occurs at the start of the tunnel test section.
Tunnel_Geom.NozzleSlice_m(:,1) = Tunnel_Geom.NozzleSlice_m(:,1) - ...
    Tunnel_Geom.NozzleSlice_m(end,1) - Tunnel_Geom.TestStart_m;
%
xframeshift = (Panel_Geom.Lframe_m - Panel_Geom.Lpanel_m)./2;
%
%%%%%%%%%%%%%%%%%%
% Generate Plots %
%%%%%%%%%%%%%%%%%%
figure('units','normalized','outerposition',[0 0 1 1]);
ax1 = axes;
set(ax1,'Units','Normalized','OuterPosition',[-0.02,0,0.7,0.45]);
hold on;
plot(Tunnel_Geom.NozzleSlice_m(:,1),-Tunnel_Geom.Wnozzle_m/2*...
    ones(size(Tunnel_Geom.NozzleSlice_m(:,1))),'-k','linewidth',2);
plot(Tunnel_Geom.NozzleSlice_m(:,1),Tunnel_Geom.Wnozzle_m/2*...
    ones(size(Tunnel_Geom.NozzleSlice_m(:,1))),'-k','linewidth',2);
plot([-Tunnel_Geom.TestStart_m,Tunnel_Geom.Ltest_m - ...
    Tunnel_Geom.TestStart_m],-Tunnel_Geom.Wtest_m./2*ones(1,2),'-',...
    'linewidth',2,'Color',[0,0.447,0.741]);
plot([-Tunnel_Geom.TestStart_m,Tunnel_Geom.Ltest_m - ...
    Tunnel_Geom.TestStart_m],Tunnel_Geom.Wtest_m./2*ones(1,2),'-',...
    'linewidth',2,'Color',[0,0.447,0.741]);
plot([0,Panel_Geom.Lpanel_m],-Panel_Geom.Wpanel_m./2*ones(1,2),...
    '-','linewidth',2,'Color',[0.85,0.325,0.098]);
plot([0,Panel_Geom.Lpanel_m],Panel_Geom.Wpanel_m./2*ones(1,2),...
    '-','linewidth',2,'Color',[0.85,0.325,0.098]);
plot(zeros(1,2),[-Panel_Geom.Wpanel_m,Panel_Geom.Wpanel_m]./2,...
    '-','linewidth',2,'Color',[0.85,0.325,0.098]);
plot(Panel_Geom.Lpanel_m*ones(1,2),[-Panel_Geom.Wpanel_m,...
    Panel_Geom.Wpanel_m]./2,'-','linewidth',2,'Color',[0.85,0.325,0.098]);
plot([0,Panel_Geom.Lframe_m] - xframeshift,-Panel_Geom.Wframe_m./2*ones(1,2),...
    '-','linewidth',2,'Color',[0.494,0.184,0.556]);
plot([0,Panel_Geom.Lframe_m] - xframeshift,Panel_Geom.Wframe_m./2*ones(1,2),...
    '-','linewidth',2,'Color',[0.494,0.184,0.556]);
plot(zeros(1,2) - xframeshift,[-Panel_Geom.Wframe_m,Panel_Geom.Wframe_m]./2,...
    '-','linewidth',2,'Color',[0.494,0.184,0.556]);
plot(Panel_Geom.Lframe_m*ones(1,2) - xframeshift,[-Panel_Geom.Wframe_m,...
    Panel_Geom.Wframe_m]./2,'-','linewidth',2,'Color',[0.494,0.184,0.556]);
if (isShock == 1)
    plot(-Wedge_Geom.WedgeLE2PanelLE_m(1)*ones(1,2),[-Wedge_Geom.Wwedge_m(1),...
        Wedge_Geom.Wwedge_m(1)]./2,'-','linewidth',2,'Color',[0.929,0.694,0.125]);
    plot(-Wedge_Geom.WedgeLE2PanelLE_m(1)*ones(1,2) + Wedge_Geom.Lwedge_m(1),...
        [-Wedge_Geom.Wwedge_m(1),Wedge_Geom.Wwedge_m(1)]./2,'-','linewidth',2,...
        'Color',[0.929,0.694,0.125]);
    plot([-Wedge_Geom.WedgeLE2PanelLE_m(1),-Wedge_Geom.WedgeLE2PanelLE_m(1) + ...
        Wedge_Geom.Lwedge_m(1)],-Wedge_Geom.Wwedge_m(1)*ones(1,2)./2,'-',...
        'linewidth',2,'Color',[0.929,0.694,0.125]);
    plot([-Wedge_Geom.WedgeLE2PanelLE_m(1),-Wedge_Geom.WedgeLE2PanelLE_m(1) + ...
        Wedge_Geom.Lwedge_m(1)],Wedge_Geom.Wwedge_m(1)*ones(1,2)./2,'-',...
        'linewidth',2,'Color',[0.929,0.694,0.125]);
end
hold off;
title('RC-19 Tunnel Top View');
xlabel('x (m)');
ylabel('y (m)');
set(gca,'FontSize',20);
%
ax2 = axes;
set(ax2,'Units','Normalized','OuterPosition',[-0.02,0.55,0.7,0.45]);
hold on;
plot(Tunnel_Geom.NozzleSlice_m(:,1),(Tunnel_Geom.NozzleSlice_m(end,2) - ...
    Tunnel_Geom.NozzleSlice_m(:,2) + Tunnel_Geom.Htest_m/2),...
    '-k','linewidth',2);
plot(Tunnel_Geom.NozzleSlice_m(:,1),-(Tunnel_Geom.NozzleSlice_m(end,2) - ...
    Tunnel_Geom.NozzleSlice_m(:,2) + Tunnel_Geom.Htest_m/2),...
    '-k','linewidth',2);
plot([-Tunnel_Geom.TestStart_m,Tunnel_Geom.Ltest_m - ...
    Tunnel_Geom.TestStart_m],-Tunnel_Geom.Htest_m./2*ones(1,2),'-',...
    'linewidth',2,'Color',[0,0.447,0.741]);
plot([-Tunnel_Geom.TestStart_m,Tunnel_Geom.Ltest_m - ...
    Tunnel_Geom.TestStart_m],Tunnel_Geom.Htest_m./2*ones(1,2),'-',...
    'linewidth',2,'Color',[0,0.447,0.741]);
plot([0,Panel_Geom.Lpanel_m],Tunnel_Geom.Htest_m./2*ones(1,2),...
    '-','linewidth',2,'Color',[0.85,0.325,0.098]);
if (isShock == 1)
    plot([-Wedge_Geom.WedgeLE2PanelLE_m(1),-Wedge_Geom.WedgeLE2PanelLE_m(1) + ...
        Wedge_Geom.Lwedge_m(1)],-Tunnel_Geom.Htest_m*ones(1,2)/2,'-','linewidth',2,...
        'Color',[0.929,0.694,0.125]);
    plot([-Wedge_Geom.WedgeLE2PanelLE_m(1),-Wedge_Geom.WedgeLE2PanelLE_m(1) + ...
        Wedge_Geom.Lwedge_m(1)],[-Tunnel_Geom.Htest_m/2,-Tunnel_Geom.Htest_m/2 + ...
        Wedge_Geom.Hwedge_m(1)],'-','linewidth',2,'Color',[0.929,0.694,0.125]);
    plot((-Wedge_Geom.WedgeLE2PanelLE_m(1) + Wedge_Geom.Lwedge_m(1))*ones(1,2),...
        [-Tunnel_Geom.Htest_m/2,-Tunnel_Geom.Htest_m/2 + Wedge_Geom.Hwedge_m(1)],...
        '-','linewidth',2,'Color',[0.929,0.694,0.125]);
end
hold off;
title('RC-19 Tunnel Mid-Span View');
xlabel('x (m)');
ylabel('z (m)');
set(gca,'FontSize',20);
%
ax3 = axes;
set(ax3,'Units','Normalized','OuterPosition',[.705,0.55,0.3,0.45]);
hold on;
plot([-Tunnel_Geom.Wtest_m,Tunnel_Geom.Wtest_m]./2,...
    -Tunnel_Geom.Htest_m./2*ones(1,2),'-','linewidth',2,...
    'Color',[0,0.447,0.741]);
plot([-Tunnel_Geom.Wtest_m,Tunnel_Geom.Wtest_m]./2,...
    Tunnel_Geom.Htest_m./2*ones(1,2),'-','linewidth',2,...
    'Color',[0,0.447,0.741]);
plot(Tunnel_Geom.Wtest_m./2*ones(1,2),[-Tunnel_Geom.Htest_m,...
    Tunnel_Geom.Htest_m]./2,'-','linewidth',2,'Color',[0,0.447,0.741]);
plot(-Tunnel_Geom.Wtest_m./2*ones(1,2),[-Tunnel_Geom.Htest_m,...
    Tunnel_Geom.Htest_m]./2,'-','linewidth',2,'Color',[0,0.447,0.741]);
plot([-Panel_Geom.Wpanel_m,Panel_Geom.Wpanel_m]./2,...
    Tunnel_Geom.Htest_m./2*ones(1,2),'-','linewidth',2,...
    'Color',[0.85,0.325,0.098]);
if (isShock == 1)
    plot([-Wedge_Geom.Wwedge_m(1),Wedge_Geom.Wwedge_m(1)]./2,...
        -Tunnel_Geom.Htest_m*ones(1,2)/2,'-','linewidth',2,...
        'Color',[0.929,0.694,0.125]);
    plot([-Wedge_Geom.Wwedge_m(1),Wedge_Geom.Wwedge_m(1)]./2,...
        (-Tunnel_Geom.Htest_m./2 + Wedge_Geom.Hwedge_m(1))*ones(1,2),'-',...
        'linewidth',2,'Color',[0.929,0.694,0.125]);
    plot(-Wedge_Geom.Wwedge_m(1)*ones(1,2)./2,[-Tunnel_Geom.Htest_m./2,...
        (-Tunnel_Geom.Htest_m./2 + Wedge_Geom.Hwedge_m(1))],'-','linewidth',2,...
        'Color',[0.929,0.694,0.125]);
    plot(Wedge_Geom.Wwedge_m(1)*ones(1,2)./2,[-Tunnel_Geom.Htest_m./2,...
        (-Tunnel_Geom.Htest_m./2 + Wedge_Geom.Hwedge_m(1))],'-','linewidth',2,...
        'Color',[0.929,0.694,0.125]);
end
hold off;
title('RC-19 Test Section Side View');
xlabel('y (m)');
ylabel('z (m)');
set(gca,'FontSize',20);
%
ax4 = axes;
set(ax4,'Units','Normalized','OuterPosition',[.705,0,0.3,0.45]);
hold on;
p1 = plot(NaN,NaN,'-k','linewidth',2);
p2 = plot(NaN,NaN,'-','Color',[0,0.447,0.741],'linewidth',2);
p3 = plot(NaN,NaN,'-','Color',[0.85,0.325,0.098],'linewidth',2);
if (isShock == 1)
    p4 = plot(NaN,NaN,'-','Color',[0.929,0.694,0.125],'linewidth',2);
end
p5 = plot(NaN,NaN,'-','Color',[0.494,0.184,0.556],'linewidth',2);
hold off;
if (isShock == 1)
    Leg = legend([p1,p2,p3,p4,p5],'Nozzle','Test Section','Thin Panel','Wedge','Frame');
else
    Leg = legend([p1,p2,p3,p5],'Nozzle','Test Section','Thin Panel','Frame');
end
set(Leg,'Units','normalized');
LegP = get(Leg,'Position');
LegP(1:2) = [0.805,0.225];
set(Leg,'position',LegP);
set(ax4,'FontSize',25);
set(ax4,'Visible','off');
%